export default {
    "message": "Unexpected token ;",
    "column": 18,
    "index": 17,
    "lineNumber": 1
}